/* --------------------------------------------------
   Template by espace（https://espace.monbalcon.net/）
   Copyright: 2020 espace.

   利用規約を遵守の上、ご利用ください。
   二次配布、販売は禁止しています。
   --------------------------------------------------*/

const animateTime = 500;
const spViewPoint = 1024;

let windowSize;
const setWindowSize = () => (windowSize = window.innerWidth);
setWindowSize();

let headerHeight;
let headerPoint;

const existsElement = (element) => {
    return typeof element !== "undefined" && element !== null;
};

//-- ▼ firefoxの:has対応
const headerElement = document.getElementsByTagName("header")[0];
const existsHeader = existsElement(headerElement);
if (existsHeader) {
    document.querySelector("body").classList.add("get-header");
}
//-- ▲ firefoxの:has対応

let scrollViewPoint;
const setScrollViewPoint = () => {
    scrollViewPoint = existsHeader ? headerElement.getBoundingClientRect().height : 100;
};
setScrollViewPoint();

const isFixMenu = document.querySelector("body").classList.contains("fix-menu");

const isSp = () => {
    return spViewPoint >= windowSize;
};

const smoothScroll = (targetY) => {
    window.scrollTo({
        top: targetY,
        behavior: "smooth",
    });
};

const getTargetTop = (targetElement) => {
    if (targetElement) {
        const rect = targetElement.getBoundingClientRect().top;
        const offset = window.pageYOffset;
        return rect + offset - (headerHeight ?? 0);
    }
};

const jumpInPage = (trigger) => {
    const href = trigger.getAttribute("href");
    const targetElement = document.getElementById(href.replace("#", ""));
    const targetPosition = getTargetTop(targetElement);
    smoothScroll(targetPosition);
};

const pageTopTrigger = document.getElementById("pageTop");
if (existsElement(pageTopTrigger)) {
    pageTopTrigger.addEventListener("click", () => smoothScroll(0));
}

const smoothScrollTrigger = document.querySelectorAll('a[href^="#"]');
smoothScrollTrigger.forEach((trigger) => {
    trigger.addEventListener("click", (e) => {
        e.preventDefault();
        jumpInPage(trigger);
    });
});

const menuElement = document.getElementById("mainMenu");
const existsMenu = existsElement(menuElement);
const menuToggler = existsMenu ? document.getElementById(menuElement.dataset.toggler) : null;

const swithMenu = (isOpen = true) => {
    menuToggler.dataset.open = isOpen;
    if (isOpen) {
        menuToggler.classList.add("open");
        menuElement.classList.add("open");
    } else {
        menuToggler.classList.remove("open");
        menuElement.classList.remove("open");
    }
};

let isUseSwitchMenu;
const setIsUseSwitchMenu = () => (isUseSwitchMenu = existsMenu && isSp());
setIsUseSwitchMenu();

let isMenuOpen = () => {
    return existsMenu && existsElement(menuToggler) ? menuToggler.dataset.open === "true" : false;
};

const scrollMenu = (isScroll = null) => {
    if (isScroll === null) {
        if (window.scrollY >= scrollViewPoint) {
            headerElement.classList.add("scroll");
        } else {
            headerElement.classList.remove("scroll");
        }
    } else {
        if (isScroll) {
            headerElement.classList.add("scroll");
        } else {
            headerElement.classList.remove("scroll");
        }
    }
};

let isUseScrollMenu;
const setIsUseScrollMenu = () => (isUseScrollMenu = existsMenu && !isSp());
setIsUseScrollMenu();

const isMenuScroll = () => {
    return existsMenu ? menuElement.classList.contains("scroll") : false;
};

if (existsMenu) {
    const menuLinks = existsMenu ? menuElement.querySelectorAll("a") : null;
    if (existsElement(menuToggler)) {
        menuToggler.addEventListener("click", () => isUseSwitchMenu && swithMenu(!isMenuOpen()));
    }
    menuLinks.forEach((element) => element.addEventListener("click", () => isUseSwitchMenu && swithMenu(false)));
}

if (isUseScrollMenu) {
    if (isFixMenu) {
        scrollMenu(true);
    } else {
        scrollMenu();
    }
}

window.addEventListener("scroll", () => {
    setIsUseSwitchMenu();
    setIsUseScrollMenu();
    isUseScrollMenu && !isFixMenu && scrollMenu();
    if (isUseSwitchMenu && isMenuOpen()) {
        swithMenu(false);
    }
});

window.addEventListener("resize", () => {
    windowSize = window.innerWidth;
    setWindowSize();
    setIsUseSwitchMenu();
    setIsUseScrollMenu();

    if (isFixMenu) {
        isUseScrollMenu && scrollMenu(true);
    } else {
        if (!isUseSwitchMenu && isMenuOpen()) {
            swithMenu(false);
        } else if (!isUseScrollMenu && isMenuScroll()) {
            scrollMenu(false);
        }
    }
});

class espHeaderImages {
    constructor() {
        this.autoTime = 5000; // 次の画像に移るまでの間隔
        this.headerImagesElement = document.getElementById("headerImages");
        this.headerImageElements = this.headerImagesElement.querySelectorAll("img");
        if (existsElement(this.headerImageElements) && this.headerImageElements.length > 0) {
            this.oldNum = null;
            this.currentNum = 0;
            this.headerImagesElement.appendChild(this.renderHeaderImagesNav(this.headerImageElements.length));
            this.headerImagesNavElement = document.getElementById("headerImagesNav");
            this.headerImagesNavButtonElements = this.headerImagesNavElement.querySelectorAll("li");
            this.switchHeaderImageActive(this.currentNum);

            [...this.headerImagesNavButtonElements].map((headerImagesNavButtonElement, headerImagesNavButtonKey) => {
                headerImagesNavButtonElement.addEventListener("click", () => this.switchHeaderImageActive(headerImagesNavButtonKey));
            });
        }

        setInterval(() => {
            if (this.currentNum === this.headerImageElements.length - 1) {
                this.switchHeaderImageActive(0);
            } else {
                this.switchHeaderImageActive(this.currentNum + 1);
            }
        }, this.autoTime);
    }

    renderHeaderImagesNav = (count) => {
        let renderNav = document.createElement("nav");
        renderNav.id = "headerImagesNav";
        let tmp = "<ul>";
        for (let num = 0; num < count; num++) {
            tmp += "<li></li>";
        }
        tmp += "</ul>";
        renderNav.innerHTML = tmp;
        return renderNav;
    };

    switchHeaderImageActive = (nextNum) => {
        if (this.oldNum !== null) {
            this.headerImageElements[this.currentNum].classList.add("old-active");
        }
        this.oldNum = this.currentNum;
        this.currentNum = nextNum;
        this.headerImageElements[this.currentNum].classList.add("active");
        if (this.oldNum) {
        }
        [...this.headerImageElements].map((headerImageElement, num) => {
            if (num !== this.currentNum) {
                headerImageElement.classList.remove("active");
            }
            if (num !== this.oldNum) {
                headerImageElement.classList.remove("old-active");
            }
        });
        if (existsElement(this.headerImagesNavElement)) {
            this.headerImagesNavButtonElements[this.currentNum].classList.add("active");
            [...this.headerImagesNavButtonElements].map((headerImagesNavButtonElement, num) => {
                if (num !== this.currentNum) {
                    headerImagesNavButtonElement.classList.remove("active");
                }
            });
        }
    };
}

window.onload = () => {
    if (existsElement(document.getElementById("headerImages"))) {
        new espHeaderImages();
    }
};
